var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Api } from "../../Api";
import { DataFrame, Method, Status } from "../../DataFrame";
import { ExalusConnectionService } from "../ExalusConnectionService";
import { ResponseResult } from "../FieldChangeResult";
import { SessionService } from "../Session/SessionService";
import { WebApiCacheService } from "../WebApi/WebApiCacheService";
import { AddNewGroupErrorCode, ChannelsGroup } from "./IChannelsGroupsService";
import { LoggerService } from "../Logging/LoggerService";
import { DevicesService } from './DevicesService';
export class ChannelsGroupsService {
    constructor() {
        this._connection = null;
        this._synchronized = false;
        this._synchronizationTaskCompletionSource = null;
        this._groups = [];
        this._connection = Api.Get(ExalusConnectionService.ServiceName);
        this._synchronizationTaskCompletionSource = new Promise((resolve) => {
            Api.Get(SessionService.ServiceName).OnUserLoggedInEvent().Subscribe((user) => __awaiter(this, void 0, void 0, function* () {
                yield this.SyncGroups();
                resolve();
                this._synchronized = true;
            }));
        });
    }
    SyncGroups() {
        return __awaiter(this, void 0, void 0, function* () {
            this._groups = yield this.GetGroupsAsync();
        });
    }
    AddDeviceChannelToGroupByGuidAsync(channel, groupGuid) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            const req = new AddDeviceChannelToGroupRequest();
            req.Data.Channel = channel.Number;
            let device = channel.GetDevice();
            if (device == null)
                throw new Error("Device is not set on this channel!");
            req.Data.DeviceGuid = (_a = channel.GetDevice()) === null || _a === void 0 ? void 0 : _a.Guid;
            req.Data.GroupGuid = groupGuid;
            const result = yield ((_b = this._connection) === null || _b === void 0 ? void 0 : _b.SendAndWaitForResponseAsync(req, 15000, false));
            Api.Get(WebApiCacheService.ServiceName).ClearCache();
            if (result != null && result.Status != null) {
                if (result.Status == Status.OK)
                    channel.ChannelGroups.push(groupGuid);
                return result.Status;
            }
            return Status.Error;
        });
    }
    RemoveDeviceChannelFromGroupByGuidAsync(channel, groupGuid) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            const req = new RemoveDeviceChannelToGroupRequest();
            let device = channel.GetDevice();
            if (device == null)
                throw new Error("Device is not set on this channel!");
            req.Data.DeviceGuid = (_a = channel.GetDevice()) === null || _a === void 0 ? void 0 : _a.Guid;
            req.Data.Channel = channel.Number;
            req.Data.GroupGuid = groupGuid;
            const result = yield ((_b = this._connection) === null || _b === void 0 ? void 0 : _b.SendAndWaitForResponseAsync(req, 15000, false));
            Api.Get(WebApiCacheService.ServiceName).ClearCache();
            if (result != null && result.Status != null) {
                if (result.Status == Status.OK)
                    channel.ChannelGroups = channel.ChannelGroups.where(a => a != groupGuid).toArray();
                return result.Status;
            }
            return Status.Error;
        });
    }
    UpsertGroupWithDevicesChannelsAsync(group, deviceChannels) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._groups.all(g => g.Guid != group.Guid)) {
                let result = yield this.AddNewGroupAsync(group.Name);
                if (result instanceof ChannelsGroup)
                    group = result;
                else if (result instanceof ResponseResult)
                    return result;
                else
                    return new ResponseResult(AddNewGroupErrorCode.UnknownError, "");
            }
            for (let channel of deviceChannels.where(a => a.ChannelGroups.all(b => b !== group.Guid))) {
                let status = yield this.AddDeviceChannelToGroupAsync(channel, group);
                if (status !== Status.OK) {
                    Api.Get(LoggerService.ServiceName).Error(ChannelsGroupsService.ServiceName, `Failed to add device channel ${channel.Name} to group ${group.Name}, controller responded with error ${status}`);
                    return new ResponseResult(AddNewGroupErrorCode.UnknownError, `Failed to add device channel ${channel.Name} to group ${group.Name}, controller responded with error ${status}`);
                }
            }
            let devices = yield Api.Get(DevicesService.ServiceName).GetDevicesAsync();
            for (let device of devices) {
                for (let channel of device.Channels.except(deviceChannels, (a, b) => a.GetDevice().Guid == b.GetDevice().Guid && a.Number == b.Number)) {
                    for (var gr of channel.ChannelGroups.where(gr => group.Guid == gr)) {
                        let status = yield this.RemoveDeviceChannelFromGroupAsync(channel, group);
                        if (status !== Status.OK) {
                            Api.Get(LoggerService.ServiceName).Error(ChannelsGroupsService.ServiceName, `Failed to remove device channel ${channel.Name} from group ${group.Name}, controller responded with error ${status}`);
                            return new ResponseResult(AddNewGroupErrorCode.UnknownError, `Failed to remove device channel ${channel.Name} from group ${group.Name}, controller responded with error ${status}`);
                        }
                    }
                }
            }
            return group;
        });
    }
    UpdateGroupWithDevicesChannelsAsync(groupGuid, deviceChannels) {
        return __awaiter(this, void 0, void 0, function* () {
            for (let channel of deviceChannels.where(a => a.ChannelGroups.all(b => b !== groupGuid))) {
                let status = yield this.AddDeviceChannelToGroupByGuidAsync(channel, groupGuid);
                if (status !== Status.OK) {
                    Api.Get(LoggerService.ServiceName).Error(ChannelsGroupsService.ServiceName, `Failed to add device channel ${channel.Name} to group ${groupGuid}, controller responded with error ${status}`);
                    return Status.FatalError;
                }
            }
            let devices = yield Api.Get(DevicesService.ServiceName).GetDevicesAsync();
            for (let device of devices) {
                for (let channel of device.Channels.except(deviceChannels, (a, b) => a.GetDevice().Guid == b.GetDevice().Guid && a.Number == b.Number)) {
                    for (var gr of channel.ChannelGroups.where(gr => groupGuid == gr)) {
                        let status = yield this.RemoveDeviceChannelFromGroupByGuidAsync(channel, groupGuid);
                        if (status !== Status.OK) {
                            Api.Get(LoggerService.ServiceName).Error(ChannelsGroupsService.ServiceName, `Failed to add device channel ${channel.Name} to group ${groupGuid}, controller responded with error ${status}`);
                            return Status.FatalError;
                        }
                    }
                }
            }
            return Status.OK;
        });
    }
    ChangeGroupNameByGuidAsync(groupGuid, name) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            let req = new AddUpdateChannelsGroupsRequest();
            let gr = new ApiGroupObject();
            gr.Guid = groupGuid;
            gr.Name = name;
            (_a = req.Data) === null || _a === void 0 ? void 0 : _a.push(gr);
            const result = yield ((_b = this._connection) === null || _b === void 0 ? void 0 : _b.SendAndWaitForResponseAsync(req, 15000, false));
            Api.Get(WebApiCacheService.ServiceName).ClearCache();
            this._groups = yield this.GetGroupsAsync();
            if (result != null && result.Status != null) {
                switch (result.Status) {
                    case Status.OK:
                        return new ResponseResult(AddNewGroupErrorCode.Success, "");
                    case Status.WrongData:
                        switch (result.Data) {
                            case "NameToShort":
                                return new ResponseResult(AddNewGroupErrorCode.NameToShort, "At least 3 characters required");
                            case "NameAlreadyExists":
                                return new ResponseResult(AddNewGroupErrorCode.NameAlreadyExists, "Group with this name already exists");
                            default:
                                return new ResponseResult(AddNewGroupErrorCode.OtherError, `Response error: ${result.Status} data: ${result.Data}`);
                        }
                    default:
                        return new ResponseResult(AddNewGroupErrorCode.OtherError, `Response error: ${result.Status} data: ${result.Data}`);
                }
            }
            return new ResponseResult(AddNewGroupErrorCode.UnknownError, "");
        });
    }
    GetServiceName() {
        return ChannelsGroupsService.ServiceName;
    }
    WaitForSynchronizationAsync() {
        return this._synchronizationTaskCompletionSource;
    }
    GetGroupByGuid(guid) {
        return this._groups.first(a => a.Guid === guid);
    }
    ChangeGroupNameAsync(group, name) {
        return this.ChangeGroupNameByGuidAsync(group.Guid, name);
    }
    RemoveGroupAsync(group) {
        return this.RemoveGroupByGuidAsync(group.Guid);
    }
    RemoveGroupByGuidAsync(groupGuid) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let req = new RemoveGroupRequest();
            req.Data = groupGuid;
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(req, 15000, false));
            Api.Get(WebApiCacheService.ServiceName).ClearCache();
            yield this.SyncGroups();
            for (let device of yield Api.Get(DevicesService.ServiceName).GetDevicesAsync()) {
                for (let channel of device.Channels) {
                    if (channel.ChannelGroups.any(a => a === groupGuid)) {
                        channel.ChannelGroups = channel.ChannelGroups.except(groupGuid, (a, b) => a === b).toArray();
                    }
                }
            }
            if (result != null && result.Status != null)
                return result === null || result === void 0 ? void 0 : result.Status;
            return Status.Error;
        });
    }
    GetGroupsAsync() {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new GetGroupsRequest(), 15000, false));
            let groups = [];
            switch (result === null || result === void 0 ? void 0 : result.Status) {
                case Status.OK:
                    let log = Api.Get(LoggerService.ServiceName);
                    (_b = result.Data) === null || _b === void 0 ? void 0 : _b.forEach(group => {
                        let gr = new ChannelsGroup();
                        gr.Guid = group.Guid;
                        gr.Name = group.Name;
                        log.Info(ChannelsGroupsService.ServiceName, `Got group: ${group.Name} ${group.Guid}`);
                        groups.push(gr);
                    });
                    return groups;
                default:
                    throw new Error(`Failed to get groups, API responded with status ${result === null || result === void 0 ? void 0 : result.Status} data: ${result === null || result === void 0 ? void 0 : result.Data}`);
            }
        });
    }
    AddDeviceChannelToGroupAsync(channel, group) {
        return this.AddDeviceChannelToGroupByGuidAsync(channel, group.Guid);
    }
    RemoveDeviceChannelFromGroupAsync(channel, group) {
        return this.RemoveDeviceChannelFromGroupByGuidAsync(channel, group.Guid);
    }
    AddNewGroupAsync(name) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            let req = new AddUpdateChannelsGroupsRequest();
            let gr = new ApiGroupObject();
            gr.Name = name;
            (_a = req.Data) === null || _a === void 0 ? void 0 : _a.push(gr);
            const result = yield ((_b = this._connection) === null || _b === void 0 ? void 0 : _b.SendAndWaitForResponseAsync(req, 15000, false));
            Api.Get(WebApiCacheService.ServiceName).ClearCache();
            this._groups = yield this.GetGroupsAsync();
            if (result != null && result.Status != null) {
                switch (result.Status) {
                    case Status.OK:
                        return this._groups.first(a => a.Name === name);
                        break;
                    case Status.WrongData:
                        switch (result.Data) {
                            case "NameToShort":
                                return new ResponseResult(AddNewGroupErrorCode.NameToShort, "At least 3 characters required");
                            case "NameAlreadyExists":
                                return new ResponseResult(AddNewGroupErrorCode.NameAlreadyExists, "Group with this name already exists");
                            default:
                                return new ResponseResult(AddNewGroupErrorCode.OtherError, `Response error: ${result.Status} data: ${result.Data}`);
                        }
                    default:
                        return new ResponseResult(AddNewGroupErrorCode.OtherError, `Response error: ${result.Status} data: ${result.Data}`);
                }
            }
            return new ResponseResult(AddNewGroupErrorCode.UnknownError, "");
        });
    }
}
ChannelsGroupsService.ServiceName = "ChannelsGroupsService";
class RemoveGroupRequest extends DataFrame {
    constructor() {
        super();
        this.Resource = "/devices/groups/group";
        this.Method = Method.Delete;
    }
}
class GetGroupsRequest extends DataFrame {
    constructor() {
        super();
        this.Resource = "/devices/groups/";
        this.Method = Method.Get;
    }
}
class AddUpdateChannelsGroupsRequest extends DataFrame {
    constructor() {
        super();
        this.Resource = "/devices/groups/group";
        this.Method = Method.Put;
        this.Data = [];
    }
}
class AddDeviceChannelToGroupRequest extends DataFrame {
    constructor() {
        super();
        this.Resource = "/devices/device/channel/groups/group/";
        this.Method = Method.Put;
        this.Data = new AddRemoveDeviceChannelToGroup();
    }
}
class RemoveDeviceChannelToGroupRequest extends DataFrame {
    constructor() {
        super();
        this.Resource = "/devices/device/channel/groups/group/";
        this.Method = Method.Delete;
        this.Data = new AddRemoveDeviceChannelToGroup();
    }
}
class ApiGroupObject {
    constructor() {
        this.Id = 0;
        this.Guid = "";
        this.Name = "";
    }
}
class AddRemoveDeviceChannelToGroup {
    constructor() {
        this.GroupGuid = "";
        this.DeviceGuid = "";
        this.Channel = 0;
    }
}
//# sourceMappingURL=ChannelsGroupsService.js.map